Module environment

Module environment 

Template environment setup and configuration

Functions

create_template_environment
Create a new template environment with all filters and functions Each language generator instance has its own environment