Module templates

Module templates 

Template name definitions and template emitter Templates are loaded via minijinja_embed from build.rs

Structs

Templates
Template-based TypeScript code emitter and template handler Templates are loaded via minijinja_embed from build.rs

Enums

TemplateName
Template name enum for type-safe template references All templates used in the TypeScript generator must be declared here Organized by FileCategory

Constants

TEMPLATE_PATHS
Template file path mapping using type-safe enum Organized by FileCategory for easier tracking